get_pollution_forecast: Returns a time series plot showing predicted pollutant levels...

Description Usage Arguments Value Examples

View source: R/get_pollution_forecast.R

Description

Performs an API request to OpenWeather Air Pollution API, retrieves weather forecast for the next 5 days, and creates a time series graph of the pollutants with their concentration levels.

Usage

1
get_pollution_forecast(lat, lon, api_key)

Arguments

lat

A double type containing geographical latitude coordinate for the location

lon

A double type containing geographical longitude coordinate for the location

api_key

A character type OpenWeather API key

Value

A ggplot object

Examples

1
get_pollution_forecast(50, 50, "APIKEY_example")

UBC-MDS/rpollution documentation built on Feb. 7, 2022, 9:12 a.m.