Description Usage Arguments Value Examples
View source: R/get_pollution_forecast.R
Performs an API request to OpenWeather Air Pollution API, retrieves weather forecast for the next 5 days, and creates a time series graph of the pollutants with their concentration levels.
1 | get_pollution_forecast(lat, lon, api_key)
|
lat |
A double type containing geographical latitude coordinate for the location |
lon |
A double type containing geographical longitude coordinate for the location |
api_key |
A character type OpenWeather API key |
A ggplot object
1 | get_pollution_forecast(50, 50, "APIKEY_example")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.